@@ -30,12 +30,12 @@ pub fn consume<P: AsRef<Path>>(
         let mut total = vec![];
 
         for process in processes.iter() {
-            if total.len() < process.value_percents[idx_c].len() {
+            if total.len() < process.values[idx_c].len() {
                 total.extend_from_slice(
-                    vec![0.0; process.value_percents[idx_c].len() - total.len()].as_slice(),
+                    vec![0.0; process.values[idx_c].len() - total.len()].as_slice(),
                 );
             }
-            for (a, b) in total.iter_mut().zip(process.value_percents[idx_c].iter()) {
+            for (a, b) in total.iter_mut().zip(process.values[idx_c].iter()) {
                 *a += *b;
             }
         }
@@ -54,7 +54,7 @@ pub fn consume<P: AsRef<Path>>(
                 max = max.max(100.0);
             }
             "mem" => {
-                caption = "Process MEM Usage";
+                caption = "Process Memory Usage";
                 unit = "M";
                 max += 100.0;
             }
@@ -76,7 +76,7 @@ pub fn consume<P: AsRef<Path>>(
             .margin(10)
             .x_label_area_size(40)
             .y_label_area_size(50)
-            .build_cartesian_2d(0..(opts.times - 1), 0f32..max)
+            .build_cartesian_2d(0..(opts.count - 1), 0f32..max)
             .unwrap();
 
         chart
@@ -89,10 +89,7 @@ pub fn consume<P: AsRef<Path>>(
             let color = Palette99::pick(idx).stroke_width(2).filled();
             chart
                 .draw_series(LineSeries::new(
-                    process.value_percents[idx_c]
-                        .clone()
-                        .into_iter()
-                        .enumerate(),
+                    process.values[idx_c].clone().into_iter().enumerate(),
                     color.clone(),
                 ))
                 .unwrap()
@@ -100,7 +97,7 @@ pub fn consume<P: AsRef<Path>>(
                     "{}({}) / AVG({:.2}{})",
                     &process.name,
                     process.pid,
-                    process.avg_percent(idx_c),
+                    process.avg_value(idx_c),
                     unit
                 ))
                 .legend(move |(x, y)| PathElement::new(vec![(x, y), (x + 20, y)], color.clone()));
@@ -142,7 +139,7 @@ pub fn consume<P: AsRef<Path>>(
                     .margin(10)
                     .x_label_area_size(40)
                     .y_label_area_size(50)
-                    .build_cartesian_2d(0..(opts.times - 1), 0f32..cpu_frequency_max)
+                    .build_cartesian_2d(0..(opts.count - 1), 0f32..cpu_frequency_max)
                     .unwrap();
 
                 chart
@@ -167,11 +164,11 @@ pub fn consume<P: AsRef<Path>>(
             }
             "sys_gpu" => {
                 chart = ChartBuilder::on(&area)
-                    .caption("System GPU Utilization", ("sans-serif", 30).into_font())
+                    .caption("System GPU Usage", ("sans-serif", 30).into_font())
                     .margin(10)
                     .x_label_area_size(40)
                     .y_label_area_size(50)
-                    .build_cartesian_2d(0..(opts.times - 1), 0.0f32..100.0f32)
+                    .build_cartesian_2d(0..(opts.count - 1), 0.0f32..100.0f32)
                     .unwrap();
 
                 chart
@@ -184,11 +181,11 @@ pub fn consume<P: AsRef<Path>>(
                     let color = Palette99::pick(idx).stroke_width(2).filled();
                     chart
                         .draw_series(LineSeries::new(
-                            info.utilization.clone().into_iter().enumerate(),
+                            info.usage.clone().into_iter().enumerate(),
                             color.clone(),
                         ))
                         .unwrap()
-                        .label(format!("GPU / AVG({:.2}%)", info.utilization_avg()))
+                        .label(format!("GPU / AVG({:.2}%)", info.usage_avg()))
                         .legend(move |(x, y)| {
                             PathElement::new(vec![(x, y), (x + 20, y)], color.clone())
                         });
